@@ -4,6 +4,7 @@ module.exports = {
   transform: {
     '^.+\\.jsx?$': 'babel-jest',
     '^.+\\.tsx?$': 'ts-jest',
+    // '^.+\\.(css|scss|sass|less)$': 'jest-preview/transforms/css'
   },
   moduleFileExtensions: ['js', 'jsx', 'ts', 'tsx'],
   moduleNameMapper: {
@@ -12,6 +13,7 @@ module.exports = {
     '\\.(css|less)$': '<rootDir>/jest/stubs/CSSStub.js',
   },
   setupFiles: ['./jest/setup.js'],
+  setupFilesAfterEnv: ['./jest/setup-after-env.js'],
   cacheDirectory: './jest/cache/',
   testEnvironment: 'jsdom',
   transformIgnorePatterns: ['node_modules/(?!(escape-string-regexp|airdcpp-apisocket))$'],
